@@ -5,10 +5,10 @@ use crate::model::BuyerType;
 use crate::{connect, Candle, ExchangeClient, Identifier, StreamIdentifier, Subscription, Trade};
 use async_trait::async_trait;
 use chrono::{DateTime, NaiveDateTime, Utc};
-use log::{error, info, warn};
 use serde::{Deserialize, Serialize};
 use tokio::sync::mpsc;
 use tokio_stream::wrappers::UnboundedReceiverStream;
+use tracing::{error, info, warn};
 
 /// [ExchangeClient] implementation for Binance.
 pub struct Binance {
